Skip to contents

A common multiverse in observational epidemiology varies which covariates adjust a target association. adjuster_sets() returns every subset of vars, from the empty set to the full set, giving 2^length(vars) specifications by default.

Usage

adjuster_sets(vars, min_size = 0L, max_size = length(vars))

Arguments

vars

Character vector of candidate adjustment covariates.

min_size, max_size

Optional integer bounds on subset size.

Value

A tibble with columns .spec_id, adjusters (a list column of character vectors), and n_adjusters.

Examples

adjuster_sets(c("age", "sex", "bmi"))
#> # A tibble: 8 × 3
#>   .spec_id adjusters n_adjusters
#>      <int> <list>          <int>
#> 1        1 <chr [0]>           0
#> 2        2 <chr [1]>           1
#> 3        3 <chr [1]>           1
#> 4        4 <chr [1]>           1
#> 5        5 <chr [2]>           2
#> 6        6 <chr [2]>           2
#> 7        7 <chr [2]>           2
#> 8        8 <chr [3]>           3